==> qmmp-0.8.6.tar.bz2: qmmp-0.8.6/src/plugins/General/copypaste/translations/copypaste_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation>C&amp;olar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation>Suplemento Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation>Sobre o suplemento Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Suplemento Qmmp Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Este suplemento permite copiar faixas entre as várias listas de reprodução</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/General/copypaste/translations/copypaste_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation>C&amp;olar</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="29"/>
        <source>Copy/Paste Plugin</source>
        <translation>Suplemento Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>About Copy/Paste Plugin</source>
        <translation>Sobre o suplemento Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Suplemento Qmmp Copy/Paste</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Este suplemento permite copiar as faixas entre as várias listas de reprodução</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
